@@ -7,5 +7,5 @@ logging.getLogger(__name__).addHandler(logging.NullHandler())
 from .sensorimotor_model.sensorimotor_model import SensorimotorModel
 from .interest_model.interest_model import InterestModel
 from .environment.environment import Environment
-from experiment.experiment import Experiment
+from experiment import Experiment, ExperimentPool
 from .agent.agent import Agent
