@@ -3,9 +3,13 @@ import importlib
 
 
 environments = {}
-for mod_name in ['simple_arm', 'pendulum', 'npendulum']:
+for mod_name in ['simple_arm', 'pendulum']:
     module = importlib.import_module('explauto.environment.{}'.format(mod_name))
     env = getattr(module, 'environment')
     conf = getattr(module, 'configurations')
     testcases = getattr(module, 'testcases')
     environments[mod_name] = (env, conf, testcases)
+
+def available_configurations(environment):
+    _, env_configs, _ = environments[environment]
+    return env_configs
