@@ -15,7 +15,7 @@ def make_arm_config(m_ndims, m_max, s_mins, s_maxs, length_ratio, noise):
                 noise=noise)
 
 low_dim = make_arm_config(3, pi/3, array([-0.5, -1.]), array([1., 1.]), 3, 0.02)
-mid_dim = make_arm_config(7, pi/3, array([-0.5, -1.]), array([1., 1.]), 3, 0.02)
+mid_dim = make_arm_config(7, pi/3, array([-0.5, -1.]), array([1., 1.]), 3./2., 0.02)
 hd_dim = make_arm_config(50, pi/12., array([-1., -1.]), array([1., 1.]), 1., 0.02)
 # hd_dim = make_arm_config(30, pi/8., array([-0.6, -0.9]), array([1., 0.9]), 1., 0.001)
 
