@@ -1,19 +1,23 @@
+from numpy import array
 from numpy.random import randint
 
 from ..environment import Environment
 
 
 class Discrete1dProgress(Environment):
-    def __init__(self, **kwargs):
-        Environment.__init__(self, ndims=2)
+    def __init__(self, m_card, s_card):
+        Environment.__init__(self, [0.], [m_card], [0.], [s_card])
 
-        self.m_card = kwargs['m_card']
-        self.s_card = kwargs['s_card']
+        self.m_card = m_card
+        self.s_card = s_card
         self.writable = [0]
         self.readable = [0, 1]
 
-    def next_state(self, ag_state):
-        m = ag_state
+    def compute_motor_command(self, m):
+        return m
+
+    def compute_sensori_effect(self, ag_state):
+        m = ag_state[0]
 
         # if m == 0:
         #     s = 2
@@ -33,5 +37,4 @@ class Discrete1dProgress(Environment):
         elif m == 6:
             s = randint(2) + 4
 
-        self.state[0] = m
-        self.state[1] = s
+        return array([s])
