@@ -14,20 +14,23 @@ class GmmInterest(InterestModel):
 
         self.measure = measure
         self.bounds = conf.bounds[:, expl_dims]
-        self.n_components = n_components
-        self.scale_t = 1  # 1. / n_samples
-        self.t = - self.scale_t * n_samples
+
+        self.step_t = 1  # 1. / n_samples
+        self.scale_t = 1. / 100.
+        self.t = - self.step_t * n_samples
         self.scale_x = conf.bounds[1, expl_dims] - conf.bounds[0, expl_dims]
-        self.scale_measure = abs(measure(numpy.zeros_like(conf.bounds[0, :]),
-                                         numpy.zeros_like(conf.bounds[0])))
+        self.measure_max = abs(measure(numpy.zeros_like(conf.bounds[0, :]),
+                                         numpy.zeros_like(conf.bounds[0, :])))
 
         self.data = numpy.zeros((n_samples, len(expl_dims) + 2))
         self.n_samples = n_samples
         self.scaler = StandardScaler()
 
+        self.n_components = 1
         for _ in range(n_samples):
             self.update(rand_bounds(conf.bounds), rand_bounds(conf.bounds))
-
+        self.n_components = n_components
+        
     def sample(self):
         x = self.gmm_choice.sample()
         x = self.scaler.inverse_transform(numpy.hstack(([0.], x.flatten(), [0.])))[1:-1]
@@ -41,14 +44,21 @@ class GmmInterest(InterestModel):
         self.data[self.t % self.n_samples, -1] = measure
         self.data[self.t % self.n_samples, 1:-1] = xy.flatten()[self.expl_dims]
 
-        self.t += self.scale_t
-        if abs(self.t % (self.n_samples * self.scale_t / 4.)) < self.scale_t:
+        self.t += self.step_t
+        # add reached point as a max competence attempt
+        self.data[self.t % self.n_samples, 0] = self.t
+        self.data[self.t % self.n_samples, -1] = self.measure_max
+        self.data[self.t % self.n_samples, 1:-1] = ms.flatten()[self.expl_dims]
+
+        self.t += self.step_t
+        if self.t != 0 and self.t % self.n_samples == 0: # abs(self.t % (self.n_samples * self.step_t / 4.)) < self.step_t:
             self.update_gmm()
 
         return self.t, xy.flatten()[self.expl_dims], measure
 
     def update_gmm(self):
         scaled_data = self.scaler.fit_transform(self.data)
+        scaled_data[:, 0] *= self.scale_t
 
         self.gmm = GMM(n_components=self.n_components, covariance_type='full')
         self.gmm.fit(numpy.array(scaled_data))
@@ -57,10 +67,10 @@ class GmmInterest(InterestModel):
     def gmm_interest(self):
         cov_t_c = numpy.array([self.gmm.covars_[k, 0, -1]
                                for k in range(self.gmm.n_components)])
-        cov_t_c = numpy.exp(cov_t_c)
-        # cov_t_c[cov_t_c <= 1e-100] = 1e-100
+        #cov_t_c = numpy.exp(cov_t_c)
+        cov_t_c[cov_t_c <= 1e-100] = 1e-100
 
-        gmm_choice = self.gmm.inference([0], range(1, len(self.expl_dims) + 1), [1.])
+        gmm_choice = self.gmm.inference([0], range(1, len(self.expl_dims) + 1), [self.scale_t])
         gmm_choice.weights_ = cov_t_c
         gmm_choice.weights_ /= numpy.array(gmm_choice.weights_).sum()
 
